@@ -2,10 +2,16 @@ import requests
 from .http import Http
 
 class Util:
-	def login(self, token):
+	async def login(self, token):
+		self.token = token
+		
 		url = "https://avatar.roblox.com/v1/avatar/set-player-avatar-type"
 		token_header = {'X-CSRF-TOKEN': token}
 
 		r = requests.post(url, headers = token_header, json = {"playerAvatarType": "R6"})
 
-		print(r)
\ No newline at end of file
+		if r:
+			print("Success")
+			print(r.body)
+		else:
+			print("Failure to login")
\ No newline at end of file
